@@ -21,19 +21,22 @@ class Wisdom(APIResource):
     _CLASS_PREFIX = 'foresights'
 
     @classmethod
-    def get_wisdom_list_with_demo(cls, api_key: str = None) -> WhatifyResponse:
+    def get_wisdom_list_with_demo(cls, search_term: str = None, api_key: str = None) -> WhatifyResponse:
         """
-        Gets the wisdoms list for the user with the demo wisdoms.
+        Gets the wisdoms list for the user with the demo wisdoms can filter with search_term.
 
         Args:
             api_key (Optional[str]): Explicit `api_key`, not required, if `Whatify.login()` was run prior.
-
-        Returns:
+            search_term (Optional[str]): the search term you want to filter
+        :return:
             WhatifyResponse: Contains mapping of wisdoms for the user.
         """
+
         requestor = APIRequestor()
         url = '{prefix}/with_demo'.format(prefix=cls._CLASS_PREFIX)
         response = requestor.get(url, api_key=api_key)['hits']
+        if search_term:
+            response = [d for d in response if str(d['name']).find(search_term) != -1]
         return response
 
     @classmethod
