@@ -137,7 +137,7 @@ class MyWhatify:
             message = None
             # data_file.drop(data_file.columns[len(df.columns) - 1], axis=1, inplace=True)
             if skip_if_exist:
-                ret_list = cls.get_prediction_list(prediction_name=data_name)
+                ret_list = cls.get_prediction_list(search_term=data_name)
                 if len(ret_list) > 0:
                     return int(ret_list[0]['id']), True, None
             try:
@@ -466,7 +466,7 @@ class MyWhatify:
         return ret_list
 
     @classmethod
-    def get_prediction_list(cls,  len=10, search_term=None):
+    def get_prediction_list(cls, len=10, search_term=None):
         with allure.step('getting the prediction list for the prediction_name: ' + str(search_term)):
             return my_toolkit.Prediction.list(search_term=search_term)['hits'][0:len]
 
@@ -572,15 +572,14 @@ class MyWhatify:
         return response
 
     @classmethod
-    def get_wisdom_list(cls):
+    def get_wisdom_list(cls, search_term: str = None):
         """
         get wisdom list for current user
         :return:
         wisdom list
         """
-        with allure.step('getting wisdom list'):
-            my_list = my_toolkit.Wisdom.get_wisdom_list_with_demo()
-            len1 = len(my_list)
+        with allure.step('getting wisdom list with search term: ' + str(search_term)):
+            my_list = my_toolkit.Wisdom.get_wisdom_list_with_demo(search_term=search_term)
         return my_list
 
     @classmethod
